from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class LearningResource(CreativeWork):
    """The LearningResource type can be used to indicate [[CreativeWork]]s (whether physical or digital) that
     have a particular and explicit orientation towards learning, education, skill acquisition, and other educational
     purposes. [[LearningResource]] is expected to be used as an addition to a primary type such as [[Book]], [[VideoObject]],
     [[Product]] etc. [[EducationEvent]] serves a similar purpose for event-like things (e.g. a [[Trip]]).
     A [[LearningResource]] may be created as a result of an [[EducationEvent]], for example by recording one.

    See: https://schema.org/LearningResource
    Model depth: 3
    """

    type_: str = Field(default="LearningResource", alias="@type", const=True)
    educationalUse: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The purpose of a work in the context of education; for example, 'assignment', 'group work'.",
    )
    learningResourceType: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.",
    )
    educationalLevel: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.",
    )
    educationalAlignment: Optional[
        Union[List[Union["AlignmentObject", str]], "AlignmentObject", str]
    ] = Field(
        default=None,
        description="An alignment to an established educational framework. This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource [[teaches]] or [[assesses]] a competency.",
    )
    competencyRequired: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource.",
    )
    assesses: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The item being described is intended to assess the competency or learning outcome defined by the referenced term.",
    )
    teaches: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.AlignmentObject import AlignmentObject



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OrderStatus import OrderStatus


class OrderDelivered(OrderStatus):
    """OrderStatus representing successful delivery of an order.

    See: https://schema.org/OrderDelivered
    Model depth: 6
    """

    type_: str = Field(default="OrderDelivered", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GameServerStatus import GameServerStatus


class OfflineTemporarily(GameServerStatus):
    """Game server status: OfflineTemporarily. Server is offline now but it can be online soon.

    See: https://schema.org/OfflineTemporarily
    Model depth: 6
    """

    type_: str = Field(default="OfflineTemporarily", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MapCategoryType import MapCategoryType


class SeatingMap(MapCategoryType):
    """A seating map.

    See: https://schema.org/SeatingMap
    Model depth: 5
    """

    type_: str = Field(default="SeatingMap", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class TouristDestination(Place):
    """A tourist destination. In principle any [[Place]] can be a [[TouristDestination]] from a [[City]], Region
     or [[Country]] to an [[AmusementPark]] or [[Hotel]]. This Type can be used on its own to describe a general
     [[TouristDestination]], or be used as an [[additionalType]] to add tourist relevant properties to any other
     [[Place]]. A [[TouristDestination]] is defined as a [[Place]] that contains, or is colocated with, one or
     more [[TouristAttraction]]s, often linked by a similar theme or interest to a particular [[touristType]].
     The [UNWTO](http://www2.unwto.org/) defines Destination (main destination of a tourism trip) as the place
     visited that is central to the decision to take the trip. (See examples below.)

    See: https://schema.org/TouristDestination
    Model depth: 3
    """

    type_: str = Field(default="TouristDestination", alias="@type", const=True)
    touristType: Optional[
        Union[List[Union[str, "Text", "Audience"]], str, "Text", "Audience"]
    ] = Field(
        default=None,
        description="Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc.",
    )
    includesAttraction: Optional[
        Union[List[Union["TouristAttraction", str]], "TouristAttraction", str]
    ] = Field(
        default=None,
        description="Attraction located at destination.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.TouristAttraction import TouristAttraction



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.ListItem import ListItem
from pydantic2_schemaorg.CreativeWork import CreativeWork


class HowToDirection(ListItem, CreativeWork):
    """A direction indicating a single action to do in the instructions for how to achieve a result.

    See: https://schema.org/HowToDirection
    Model depth: 3
    """

    type_: str = Field(default="HowToDirection", alias="@type", const=True)
    supply: Optional[
        Union[List[Union[str, "Text", "HowToSupply"]], str, "Text", "HowToSupply"]
    ] = Field(
        default=None,
        description="A sub-property of instrument. A supply consumed when performing instructions or a direction.",
    )
    totalTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The total time required to perform instructions or a direction (including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    beforeMedia: Optional[
        Union[
            List[Union[AnyUrl, "URL", "MediaObject", str]],
            AnyUrl,
            "URL",
            "MediaObject",
            str,
        ]
    ] = Field(
        default=None,
        description="A media object representing the circumstances before performing this direction.",
    )
    duringMedia: Optional[
        Union[
            List[Union[AnyUrl, "URL", "MediaObject", str]],
            AnyUrl,
            "URL",
            "MediaObject",
            str,
        ]
    ] = Field(
        default=None,
        description="A media object representing the circumstances while performing this direction.",
    )
    afterMedia: Optional[
        Union[
            List[Union[AnyUrl, "URL", "MediaObject", str]],
            AnyUrl,
            "URL",
            "MediaObject",
            str,
        ]
    ] = Field(
        default=None,
        description="A media object representing the circumstances after performing this direction.",
    )
    prepTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The length of time it takes to prepare the items to be used in instructions or a direction, in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    performTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    tool: Optional[
        Union[List[Union[str, "Text", "HowToTool"]], str, "Text", "HowToTool"]
    ] = Field(
        default=None,
        description="A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.HowToSupply import HowToSupply
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MediaObject import MediaObject
    from pydantic2_schemaorg.HowToTool import HowToTool



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store


class BookStore(Store):
    """A bookstore.

    See: https://schema.org/BookStore
    Model depth: 5
    """

    type_: str = Field(default="BookStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaGallery import MediaGallery


class VideoGallery(MediaGallery):
    """Web page type: Video gallery page.

    See: https://schema.org/VideoGallery
    Model depth: 6
    """

    type_: str = Field(default="VideoGallery", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union
from pydantic.v1 import StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class MonetaryAmount(StructuredValue):
    """A monetary value or range. This type can be used to describe an amount of money such as $50 USD, or a range as in
     describing a bank account being suitable for a balance between £1,000 and £1,000,000 GBP, or the value of a
     salary, etc. It is recommended to use [[PriceSpecification]] Types to describe the price of an Offer, Invoice,
     etc.

    See: https://schema.org/MonetaryAmount
    Model depth: 4
    """

    type_: str = Field(default="MonetaryAmount", alias="@type", const=True)
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    maxValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The upper value of some characteristic or property.",
    )
    currency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    value: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    StrictBool,
                    "Boolean",
                    str,
                    "Text",
                    "StructuredValue",
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            StrictBool,
            "Boolean",
            str,
            "Text",
            "StructuredValue",
        ]
    ] = Field(
        default=None,
        description="The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node. * For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'. * For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    minValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The lower value of some characteristic or property.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.StructuredValue import StructuredValue



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ListItem import ListItem


class HowToItem(ListItem):
    """An item used as either a tool or supply when performing the instructions for how to achieve a result.

    See: https://schema.org/HowToItem
    Model depth: 4
    """

    type_: str = Field(default="HowToItem", alias="@type", const=True)
    requiredQuantity: Optional[
        Union[
            List[
                Union[
                    StrictInt, StrictFloat, "Number", str, "Text", "QuantitativeValue"
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="The required quantity of the item(s).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration


class RegularPrice(PriceTypeEnumeration):
    """Represents the regular price (typically the previous advertised price before a sale) of an offered product.
     Often displayed as a strike-through price.

    See: https://schema.org/RegularPrice
    Model depth: 5
    """

    type_: str = Field(default="RegularPrice", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy


class PhysicalTherapy(MedicalTherapy):
    """A process of progressive physical care and rehabilitation aimed at improving a health condition.

    See: https://schema.org/PhysicalTherapy
    Model depth: 6
    """

    type_: str = Field(default="PhysicalTherapy", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class BroadcastService(Service):
    """A delivery service through which content is provided via broadcast over the air or online.

    See: https://schema.org/BroadcastService
    Model depth: 4
    """

    type_: str = Field(default="BroadcastService", alias="@type", const=True)
    hasBroadcastChannel: Optional[
        Union[List[Union["BroadcastChannel", str]], "BroadcastChannel", str]
    ] = Field(
        default=None,
        description="A broadcast channel of a broadcast service.",
    )
    broadcastDisplayName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The name displayed in the channel guide. For many US affiliates, it is the network name.",
        )
    )
    broadcastTimezone: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The timezone in [ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601) for which the service bases its broadcasts.",
    )
    inLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]].",
    )
    videoFormat: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).",
    )
    broadcastFrequency: Optional[
        Union[
            List[Union[str, "Text", "BroadcastFrequencySpecification"]],
            str,
            "Text",
            "BroadcastFrequencySpecification",
        ]
    ] = Field(
        default=None,
        description='The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".',
    )
    area: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The area within which users can expect to reach the broadcast service.",
    )
    broadcaster: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The organization owning or operating the broadcast service.",
    )
    callSign: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A [callsign](https://en.wikipedia.org/wiki/Call_sign), as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.",
    )
    broadcastAffiliateOf: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The media network(s) whose content is broadcast on this station.",
    )
    parentService: Optional[
        Union[List[Union["BroadcastService", str]], "BroadcastService", str]
    ] = Field(
        default=None,
        description="A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.BroadcastChannel import BroadcastChannel
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.BroadcastFrequencySpecification import (
        BroadcastFrequencySpecification,
    )
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject


class _3DModel(MediaObject):
    """A 3D model represents some kind of 3D content, which may have [[encoding]]s in one or more [[MediaObject]]s.
     Many 3D formats are available (e.g. see [Wikipedia](https://en.wikipedia.org/wiki/Category:3D_graphics_file_formats));
     specific encoding formats can be represented using the [[encodingFormat]] property applied to the relevant
     [[MediaObject]]. For the case of a single file published after Zip compression, the convention of appending
     '+zip' to the [[encodingFormat]] can be used. Geospatial, AR/VR, artistic/animation, gaming, engineering
     and scientific content can all be represented using [[3DModel]].

    See: https://schema.org/3DModel
    Model depth: 4
    """

    type_: str = Field(default="3DModel", alias="@type", const=True)
    isResizable: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether the 3DModel allows resizing. For example, room layout applications often do not allow 3DModel elements to be resized to reflect reality.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TradeAction import TradeAction


class BuyAction(TradeAction):
    """The act of giving money to a seller in exchange for goods or services rendered. An agent buys an object, product,
     or service from a seller for a price. Reciprocal of SellAction.

    See: https://schema.org/BuyAction
    Model depth: 4
    """

    type_: str = Field(default="BuyAction", alias="@type", const=True)
    seller: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.",
    )
    vendor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="'vendor' is an earlier term for 'seller'.",
    )
    warrantyPromise: Optional[
        Union[List[Union["WarrantyPromise", str]], "WarrantyPromise", str]
    ] = Field(
        default=None,
        description="The warranty promise(s) included in the offer.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.WarrantyPromise import WarrantyPromise



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalActivity import PhysicalActivity
from pydantic2_schemaorg.CreativeWork import CreativeWork


class ExercisePlan(PhysicalActivity, CreativeWork):
    """Fitness-related activity designed for a specific health-related purpose, including defined exercise
     routines as well as activity prescribed by a clinician.

    See: https://schema.org/ExercisePlan
    Model depth: 3
    """

    type_: str = Field(default="ExercisePlan", alias="@type", const=True)
    restPeriods: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="How often one should break from the activity.",
    )
    workload: Optional[
        Union[
            List[Union["Energy", "QuantitativeValue", str]],
            "Energy",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure.",
    )
    repetitions: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of times one should repeat the activity.",
    )
    intensity: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement.",
    )
    activityFrequency: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="How often one should engage in the activity.",
    )
    activityDuration: Optional[
        Union[
            List[Union["Duration", "QuantitativeValue", str]],
            "Duration",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Length of time to engage in the activity.",
    )
    exerciseType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.",
    )
    additionalVariable: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Energy import Energy
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Duration import Duration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ControlAction import ControlAction


class ResumeAction(ControlAction):
    """The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume
     a timer).

    See: https://schema.org/ResumeAction
    Model depth: 4
    """

    type_: str = Field(default="ResumeAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Trip import Trip


class Flight(Trip):
    """An airline flight.

    See: https://schema.org/Flight
    Model depth: 4
    """

    type_: str = Field(default="Flight", alias="@type", const=True)
    boardingPolicy: Optional[
        Union[List[Union["BoardingPolicyType", str]], "BoardingPolicyType", str]
    ] = Field(
        default=None,
        description="The type of boarding policy used by the airline (e.g. zone-based or group-based).",
    )
    departureGate: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Identifier of the flight's departure gate.",
    )
    mealService: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Description of the meals that will be provided or available for purchase.",
    )
    departureAirport: Optional[Union[List[Union["Airport", str]], "Airport", str]] = (
        Field(
            default=None,
            description="The airport where the flight originates.",
        )
    )
    seller: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.",
    )
    flightDistance: Optional[
        Union[List[Union[str, "Text", "Distance"]], str, "Text", "Distance"]
    ] = Field(
        default=None,
        description="The distance of the flight.",
    )
    arrivalTerminal: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Identifier of the flight's arrival terminal.",
    )
    estimatedFlightDuration: Optional[
        Union[List[Union[str, "Text", "Duration"]], str, "Text", "Duration"]
    ] = Field(
        default=None,
        description="The estimated time the flight will take.",
    )
    flightNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unique identifier for a flight including the airline IATA code. For example, if describing United flight 110, where the IATA code for United is 'UA', the flightNumber is 'UA110'.",
    )
    departureTerminal: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Identifier of the flight's departure terminal.",
    )
    aircraft: Optional[
        Union[List[Union[str, "Text", "Vehicle"]], str, "Text", "Vehicle"]
    ] = Field(
        default=None,
        description='The kind of aircraft (e.g., "Boeing 747").',
    )
    webCheckinTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The time when a passenger can check into the flight online.",
    )
    carrier: Optional[Union[List[Union["Organization", str]], "Organization", str]] = (
        Field(
            default=None,
            description="'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.",
        )
    )
    arrivalAirport: Optional[Union[List[Union["Airport", str]], "Airport", str]] = (
        Field(
            default=None,
            description="The airport where the flight terminates.",
        )
    )
    arrivalGate: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Identifier of the flight's arrival gate.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.BoardingPolicyType import BoardingPolicyType
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Airport import Airport
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Distance import Distance
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Vehicle import Vehicle
    from pydantic2_schemaorg.DateTime import DateTime



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PlayAction import PlayAction


class PerformAction(PlayAction):
    """The act of participating in performance arts.

    See: https://schema.org/PerformAction
    Model depth: 4
    """

    type_: str = Field(default="PerformAction", alias="@type", const=True)
    entertainmentBusiness: Optional[
        Union[List[Union["EntertainmentBusiness", str]], "EntertainmentBusiness", str]
    ] = Field(
        default=None,
        description="A sub property of location. The entertainment business where the action occurred.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.EntertainmentBusiness import EntertainmentBusiness



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BroadcastService import BroadcastService


class RadioBroadcastService(BroadcastService):
    """A delivery service through which radio content is provided via broadcast over the air or online.

    See: https://schema.org/RadioBroadcastService
    Model depth: 5
    """

    type_: str = Field(default="RadioBroadcastService", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalExam import PhysicalExam


class Ear(PhysicalExam):
    """Ear function assessment with clinical examination.

    See: https://schema.org/Ear
    Model depth: 5
    """

    type_: str = Field(default="Ear", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
    MedicalObservationalStudyDesign,
)


class Registry(MedicalObservationalStudyDesign):
    """A registry-based study design.

    See: https://schema.org/Registry
    Model depth: 6
    """

    type_: str = Field(default="Registry", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MusicAlbumReleaseType(Enumeration):
    """The kind of release which this album is: single, EP or album.

    See: https://schema.org/MusicAlbumReleaseType
    Model depth: 4
    """

    type_: str = Field(default="MusicAlbumReleaseType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class WebAPI(Service):
    """An application programming interface accessible over Web/Internet technologies.

    See: https://schema.org/WebAPI
    Model depth: 4
    """

    type_: str = Field(default="WebAPI", alias="@type", const=True)
    documentation: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="Further documentation describing the Web API in more detail.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class ChildCare(LocalBusiness):
    """A Childcare center.

    See: https://schema.org/ChildCare
    Model depth: 4
    """

    type_: str = Field(default="ChildCare", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EmergencyService import EmergencyService
from pydantic2_schemaorg.CivicStructure import CivicStructure


class FireStation(EmergencyService, CivicStructure):
    """A fire station. With firemen.

    See: https://schema.org/FireStation
    Model depth: 4
    """

    type_: str = Field(default="FireStation", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class FinancialProduct(Service):
    """A product provided to consumers and businesses by financial institutions such as banks, insurance companies,
     brokerage firms, consumer finance companies, and investment companies which comprise the financial services
     industry.

    See: https://schema.org/FinancialProduct
    Model depth: 4
    """

    type_: str = Field(default="FinancialProduct", alias="@type", const=True)
    feesAndCommissionsSpecification: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.",
    )
    annualPercentageRate: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan. This includes any fees or additional costs associated with the transaction.",
    )
    interestRate: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The interest rate, charged or paid, applicable to the financial product. Note: This is different from the calculated annualPercentageRate.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreateAction import CreateAction


class PaintAction(CreateAction):
    """The act of producing a painting, typically with paint and canvas as instruments.

    See: https://schema.org/PaintAction
    Model depth: 4
    """

    type_: str = Field(default="PaintAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DriveWheelConfigurationValue import (
    DriveWheelConfigurationValue,
)


class FrontWheelDriveConfiguration(DriveWheelConfigurationValue):
    """Front-wheel drive is a transmission layout where the engine drives the front wheels.

    See: https://schema.org/FrontWheelDriveConfiguration
    Model depth: 6
    """

    type_: str = Field(
        default="FrontWheelDriveConfiguration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Vessel(AnatomicalStructure):
    """A component of the human body circulatory system comprised of an intricate network of hollow tubes that transport
     blood throughout the entire body.

    See: https://schema.org/Vessel
    Model depth: 4
    """

    type_: str = Field(default="Vessel", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Rheumatologic(MedicalSpecialty):
    """A specific branch of medical science that deals with the study and treatment of rheumatic, autoimmune or joint
     diseases.

    See: https://schema.org/Rheumatologic
    Model depth: 6
    """

    type_: str = Field(default="Rheumatologic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl
from datetime import date, datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Demand(Intangible):
    """A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement
     by an organization or person to seek a certain type of goods or services. For describing demand using this type,
     the very same properties used for Offer apply.

    See: https://schema.org/Demand
    Model depth: 3
    """

    type_: str = Field(default="Demand", alias="@type", const=True)
    warranty: Optional[
        Union[List[Union["WarrantyPromise", str]], "WarrantyPromise", str]
    ] = Field(
        default=None,
        description="The warranty promise(s) included in the offer.",
    )
    eligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid. See also [[ineligibleRegion]].",
    )
    gtin8: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    gtin: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description='A Global Trade Item Number ([GTIN](https://www.gs1.org/standards/id-keys/gtin)). GTINs identify trade items, including products and services, using numeric identification codes. A correct [[gtin]] value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a "GS1 Digital Link" URL based on such a string. The numeric component should also have a [valid GS1 check digit](https://www.gs1.org/services/check-digit-calculator) and meet the other rules for valid GTINs. See also [GS1\'s GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) and [Wikipedia](https://en.wikipedia.org/wiki/Global_Trade_Item_Number) for more details. Left-padding of the gtin values is not required or encouraged. The [[gtin]] property generalizes the earlier [[gtin8]], [[gtin12]], [[gtin13]], and [[gtin14]] properties. The GS1 [digital link specifications](https://www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the [[hasGS1DigitalLink]] attribute. Note also that this is a definition for how to include GTINs in Schema.org data, and not a definition of GTINs in general - see the GS1 documentation for authoritative details.',
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    inventoryLevel: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The current approximate inventory level for the item or items.",
    )
    itemCondition: Optional[
        Union[List[Union["OfferItemCondition", str]], "OfferItemCondition", str]
    ] = Field(
        default=None,
        description="A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.",
    )
    sku: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.",
    )
    eligibleTransactionVolume: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.",
    )
    includesObject: Optional[
        Union[List[Union["TypeAndQuantityNode", str]], "TypeAndQuantityNode", str]
    ] = Field(
        default=None,
        description="This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].",
    )
    availability: Optional[
        Union[List[Union["ItemAvailability", str]], "ItemAvailability", str]
    ] = Field(
        default=None,
        description="The availability of this item&#x2014;for example In stock, Out of stock, Pre-order, etc.",
    )
    seller: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.",
    )
    businessFunction: Optional[
        Union[List[Union["BusinessFunction", str]], "BusinessFunction", str]
    ] = Field(
        default=None,
        description="The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.",
    )
    eligibleDuration: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The duration for which the given offer is valid.",
    )
    eligibleCustomerType: Optional[
        Union[List[Union["BusinessEntityType", str]], "BusinessEntityType", str]
    ] = Field(
        default=None,
        description="The type(s) of customers for which the given offer is valid.",
    )
    eligibleQuantity: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.",
    )
    acceptedPaymentMethod: Optional[
        Union[
            List[Union["PaymentMethod", "LoanOrCredit", str]],
            "PaymentMethod",
            "LoanOrCredit",
            str,
        ]
    ] = Field(
        default=None,
        description="The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.",
    )
    gtin14: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-14 code of the product, or the product to which the offer refers. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    deliveryLeadTime: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.",
    )
    serialNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.",
    )
    gtin13: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    gtin12: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    areaServed: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape", "AdministrativeArea"]],
            str,
            "Text",
            "Place",
            "GeoShape",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The geographic area where a service or offered item is provided.",
    )
    asin: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from [Wikipedia](https://en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article). Note also that this is a definition for how to include ASINs in Schema.org data, and not a definition of ASINs in general - see documentation from Amazon for authoritative details. ASINs are most commonly encoded as text strings, but the [asin] property supports URL/URI as potential values too.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )
    availabilityEnds: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end of the availability of the product or service included in the offer.",
    )
    availableDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="The delivery method(s) available for this offer.",
    )
    priceSpecification: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="One or more detailed price specifications, indicating the unit price and delivery or payment charges.",
    )
    availabilityStarts: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The beginning of the availability of the product or service included in the offer.",
    )
    itemOffered: Optional[
        Union[
            List[
                Union[
                    "Service",
                    "Event",
                    "CreativeWork",
                    "Trip",
                    "MenuItem",
                    "Product",
                    "AggregateOffer",
                    str,
                ]
            ],
            "Service",
            "Event",
            "CreativeWork",
            "Trip",
            "MenuItem",
            "Product",
            "AggregateOffer",
            str,
        ]
    ] = Field(
        default=None,
        description="An item being offered (or demanded). The transactional nature of the offer or demand is documented using [[businessFunction]], e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    advanceBookingRequirement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The amount of time that is required between accepting the offer and the actual usage of the resource or service.",
    )
    mpn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.",
    )
    ineligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed. See also [[eligibleRegion]].",
    )
    availableAtOrFrom: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The place(s) from which the offer can be obtained (e.g. store locations).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.WarrantyPromise import WarrantyPromise
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.OfferItemCondition import OfferItemCondition
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.TypeAndQuantityNode import TypeAndQuantityNode
    from pydantic2_schemaorg.ItemAvailability import ItemAvailability
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.BusinessFunction import BusinessFunction
    from pydantic2_schemaorg.BusinessEntityType import BusinessEntityType
    from pydantic2_schemaorg.PaymentMethod import PaymentMethod
    from pydantic2_schemaorg.LoanOrCredit import LoanOrCredit
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Trip import Trip
    from pydantic2_schemaorg.MenuItem import MenuItem
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.AggregateOffer import AggregateOffer



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.OrganizeAction import OrganizeAction


class PlanAction(OrganizeAction):
    """The act of planning the execution of an event/task/action/reservation/plan to a future date.

    See: https://schema.org/PlanAction
    Model depth: 4
    """

    type_: str = Field(default="PlanAction", alias="@type", const=True)
    scheduledTime: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The time the object is scheduled to.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration


class ReturnByMail(ReturnMethodEnumeration):
    """Specifies that product returns must be done by mail.

    See: https://schema.org/ReturnByMail
    Model depth: 5
    """

    type_: str = Field(default="ReturnByMail", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PeopleAudience import PeopleAudience
from pydantic2_schemaorg.Audience import Audience


class MedicalAudience(PeopleAudience, Audience):
    """Target audiences for medical web pages.

    See: https://schema.org/MedicalAudience
    Model depth: 4
    """

    type_: str = Field(default="MedicalAudience", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class WebContent(CreativeWork):
    """WebContent is a type representing all [[WebPage]], [[WebSite]] and [[WebPageElement]] content. It is sometimes
     the case that detailed distinctions between Web pages, sites and their parts are not always important or obvious.
     The [[WebContent]] type makes it easier to describe Web-addressable content without requiring such distinctions
     to always be stated. (The intent is that the existing types [[WebPage]], [[WebSite]] and [[WebPageElement]]
     will eventually be declared as subtypes of [[WebContent]].)

    See: https://schema.org/WebContent
    Model depth: 3
    """

    type_: str = Field(default="WebContent", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class DataFeedItem(Intangible):
    """A single item within a larger data feed.

    See: https://schema.org/DataFeedItem
    Model depth: 3
    """

    type_: str = Field(default="DataFeedItem", alias="@type", const=True)
    item: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').",
    )
    dateCreated: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date on which the CreativeWork was created or the item was added to a DataFeed.",
    )
    dateModified: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.",
    )
    dateDeleted: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The datetime the item was removed from the DataFeed.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure


class RVPark(CivicStructure):
    """A place offering space for \"Recreational Vehicles\", Caravans, mobile homes and the like.

    See: https://schema.org/RVPark
    Model depth: 4
    """

    type_: str = Field(default="RVPark", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.IPTCDigitalSourceEnumeration import (
    IPTCDigitalSourceEnumeration,
)


class PrintDigitalSource(IPTCDigitalSourceEnumeration):
    """Content coded as '<a href=\"https://cv.iptc.org/newscodes/digitalsourcetype/print\">print</a>'
     using the IPTC <a href=\"https://cv.iptc.org/newscodes/digitalsourcetype/\">digital source type</a>
     vocabulary.

    See: https://schema.org/PrintDigitalSource
    Model depth: 6
    """

    type_: str = Field(default="PrintDigitalSource", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Product import Product


class ProductGroup(Product):
    """A ProductGroup represents a group of [[Product]]s that vary only in certain well-described ways, such as
     by [[size]], [[color]], [[material]] etc. While a ProductGroup itself is not directly offered for sale,
     the various varying products that it represents can be. The ProductGroup serves as a prototype or template,
     standing in for all of the products who have an [[isVariantOf]] relationship to it. As such, properties (including
     additional types) can be applied to the ProductGroup to represent characteristics shared by each of the (possibly
     very many) variants. Properties that reference a ProductGroup are not included in this mechanism; neither
     are the following specific properties [[variesBy]], [[hasVariant]], [[url]].

    See: https://schema.org/ProductGroup
    Model depth: 3
    """

    type_: str = Field(default="ProductGroup", alias="@type", const=True)
    hasVariant: Optional[Union[List[Union["Product", str]], "Product", str]] = Field(
        default=None,
        description="Indicates a [[Product]] that is a member of this [[ProductGroup]] (or [[ProductModel]]).",
    )
    variesBy: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description='Indicates the property or properties by which the variants in a [[ProductGroup]] vary, e.g. their size, color etc. Schema.org properties can be referenced by their short name e.g. "color"; terms defined elsewhere can be referenced with their URIs.',
    )
    productGroupID: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Indicates a textual identifier for a ProductGroup.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Code(CreativeWork):
    """Computer programming source code. Example: Full (compile ready) solutions, code snippet samples, scripts,
     templates.

    See: https://schema.org/Code
    Model depth: 3
    """

    type_: str = Field(default="Code", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class HyperToc(CreativeWork):
    """A HyperToc represents a hypertext table of contents for complex media objects, such as [[VideoObject]],
     [[AudioObject]]. Items in the table of contents are indicated using the [[tocEntry]] property, and typed
     [[HyperTocEntry]]. For cases where the same larger work is split into multiple files, [[associatedMedia]]
     can be used on individual [[HyperTocEntry]] items.

    See: https://schema.org/HyperToc
    Model depth: 3
    """

    type_: str = Field(default="HyperToc", alias="@type", const=True)
    associatedMedia: Optional[
        Union[List[Union["MediaObject", str]], "MediaObject", str]
    ] = Field(
        default=None,
        description="A media object that encodes this CreativeWork. This property is a synonym for encoding.",
    )
    tocEntry: Optional[
        Union[List[Union["HyperTocEntry", str]], "HyperTocEntry", str]
    ] = Field(
        default=None,
        description="Indicates a [[HyperTocEntry]] in a [[HyperToc]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MediaObject import MediaObject
    from pydantic2_schemaorg.HyperTocEntry import HyperTocEntry



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory


class OccupationalActivity(PhysicalActivityCategory):
    """Any physical activity engaged in for job-related purposes. Examples may include waiting tables, maid service,
     carrying a mailbag, picking fruits or vegetables, construction work, etc.

    See: https://schema.org/OccupationalActivity
    Model depth: 5
    """

    type_: str = Field(default="OccupationalActivity", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MeasurementTypeEnumeration(Enumeration):
    """Enumeration of common measurement types (or dimensions), for example \"chest\" for a person, \"inseam\"
     for pants, \"gauge\" for screws, or \"wheel\" for bicycles.

    See: https://schema.org/MeasurementTypeEnumeration
    Model depth: 4
    """

    type_: str = Field(default="MeasurementTypeEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SteeringPositionValue import SteeringPositionValue


class RightHandDriving(SteeringPositionValue):
    """The steering position is on the right side of the vehicle (viewed from the main direction of driving).

    See: https://schema.org/RightHandDriving
    Model depth: 6
    """

    type_: str = Field(default="RightHandDriving", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct


class CurrencyConversionService(FinancialProduct):
    """A service to convert funds from one currency to another currency.

    See: https://schema.org/CurrencyConversionService
    Model depth: 5
    """

    type_: str = Field(default="CurrencyConversionService", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EducationalOrganization import EducationalOrganization


class CollegeOrUniversity(EducationalOrganization):
    """A college, university, or other third-level educational institution.

    See: https://schema.org/CollegeOrUniversity
    Model depth: 4
    """

    type_: str = Field(default="CollegeOrUniversity", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class SideEffectsHealthAspect(HealthAspectEnumeration):
    """Side effects that can be observed from the usage of the topic.

    See: https://schema.org/SideEffectsHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="SideEffectsHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FindAction import FindAction


class CheckAction(FindAction):
    """An agent inspects, determines, investigates, inquires, or examines an object's accuracy, quality, condition,
     or state.

    See: https://schema.org/CheckAction
    Model depth: 4
    """

    type_: str = Field(default="CheckAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTrialDesign import MedicalTrialDesign


class SingleBlindedTrial(MedicalTrialDesign):
    """A trial design in which the researcher knows which treatment the patient was randomly assigned to but the patient
     does not.

    See: https://schema.org/SingleBlindedTrial
    Model depth: 6
    """

    type_: str = Field(default="SingleBlindedTrial", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class CourseInstance(Event):
    """An instance of a [[Course]] which is distinct from other instances because it is offered at a different time
     or location or through different media or modes of study or to a specific section of students.

    See: https://schema.org/CourseInstance
    Model depth: 3
    """

    type_: str = Field(default="CourseInstance", alias="@type", const=True)
    courseMode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description='The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous).',
    )
    instructor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A person assigned to instruct or provide instructional assistance for the [[CourseInstance]].",
    )
    courseWorkload: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type. For example, "2 hours of lectures, 1 hour of lab work and 3 hours of independent study per week".',
    )
    courseSchedule: Optional[Union[List[Union["Schedule", str]], "Schedule", str]] = (
        Field(
            default=None,
            description="Represents the length and pace of a course, expressed as a [[Schedule]].",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Schedule import Schedule



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalDevice(MedicalEntity):
    """Any object used in a medical capacity, such as to diagnose or treat a patient.

    See: https://schema.org/MedicalDevice
    Model depth: 3
    """

    type_: str = Field(default="MedicalDevice", alias="@type", const=True)
    seriousAdverseOutcome: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.",
    )
    contraindication: Optional[
        Union[
            List[Union[str, "Text", "MedicalContraindication"]],
            str,
            "Text",
            "MedicalContraindication",
        ]
    ] = Field(
        default=None,
        description="A contraindication for this therapy.",
    )
    postOp: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A description of the postoperative procedures, care, and/or followups for this device.",
    )
    preOp: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A description of the workup, testing, and other preparations required before implanting this device.",
    )
    procedure: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A description of the procedure involved in setting up, using, and/or installing the device.",
    )
    adverseOutcome: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalContraindication import MedicalContraindication



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration


class MSRP(PriceTypeEnumeration):
    """Represents the manufacturer suggested retail price (\"MSRP\") of an offered product.

    See: https://schema.org/MSRP
    Model depth: 5
    """

    type_: str = Field(default="MSRP", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Blog(CreativeWork):
    """A [blog](https://en.wikipedia.org/wiki/Blog), sometimes known as a \"weblog\". Note that the individual
     posts ([[BlogPosting]]s) in a [[Blog]] are often colloquially referred to by the same term.

    See: https://schema.org/Blog
    Model depth: 3
    """

    type_: str = Field(default="Blog", alias="@type", const=True)
    issn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.",
    )
    blogPost: Optional[Union[List[Union["BlogPosting", str]], "BlogPosting", str]] = (
        Field(
            default=None,
            description="A posting that is part of this blog.",
        )
    )
    blogPosts: Optional[Union[List[Union["BlogPosting", str]], "BlogPosting", str]] = (
        Field(
            default=None,
            description='Indicates a post that is part of a [[Blog]]. Note that historically, what we term a "Blog" was once known as a "weblog", and that what we term a "BlogPosting" is now often colloquially referred to as a "blog".',
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BlogPosting import BlogPosting



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class HealthInsurancePlan(Intangible):
    """A US-style health insurance plan, including PPOs, EPOs, and HMOs.

    See: https://schema.org/HealthInsurancePlan
    Model depth: 3
    """

    type_: str = Field(default="HealthInsurancePlan", alias="@type", const=True)
    includesHealthPlanNetwork: Optional[
        Union[List[Union["HealthPlanNetwork", str]], "HealthPlanNetwork", str]
    ] = Field(
        default=None,
        description="Networks covered by this plan.",
    )
    healthPlanMarketingUrl: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="The URL that goes directly to the plan brochure for the specific standard plan or plan variation.",
    )
    usesHealthPlanIdStandard: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description='The standard for interpreting the Plan ID. The preferred is "HIOS". See the Centers for Medicare & Medicaid Services for more details.',
    )
    healthPlanId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The 14-character, HIOS-generated Plan ID number. (Plan IDs must be unique, even across different markets.)",
    )
    benefitsSummaryUrl: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="The URL that goes directly to the summary of benefits and coverage for the specific standard plan or plan variation.",
    )
    contactPoint: Optional[
        Union[List[Union["ContactPoint", str]], "ContactPoint", str]
    ] = Field(
        default=None,
        description="A contact point for a person or organization.",
    )
    includesHealthPlanFormulary: Optional[
        Union[List[Union["HealthPlanFormulary", str]], "HealthPlanFormulary", str]
    ] = Field(
        default=None,
        description="Formularies covered by this plan.",
    )
    healthPlanDrugOption: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="TODO.",
        )
    )
    healthPlanDrugTier: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The tier(s) of drugs offered by this formulary or insurance plan.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.HealthPlanNetwork import HealthPlanNetwork
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.HealthPlanFormulary import HealthPlanFormulary



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class FlightReservation(Reservation):
    """A reservation for air travel. Note: This type is for information about actual reservations, e.g. in confirmation
     emails or HTML pages with individual confirmations of reservations. For offers of tickets, use [[Offer]].

    See: https://schema.org/FlightReservation
    Model depth: 4
    """

    type_: str = Field(default="FlightReservation", alias="@type", const=True)
    passengerPriorityStatus: Optional[
        Union[
            List[Union[str, "Text", "QualitativeValue"]],
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The priority status assigned to a passenger for security or boarding (e.g. FastTrack or Priority).",
    )
    securityScreening: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The type of security screening the passenger is subject to.",
    )
    passengerSequenceNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The passenger's sequence number as assigned by the airline.",
        )
    )
    boardingGroup: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The airline-specific indicator of boarding order / preference.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class WeaponConsideration(AdultOrientedEnumeration):
    """The item is intended to induce bodily harm, for example guns, mace, combat knives, brass knuckles, nail or
     other bombs, and spears.

    See: https://schema.org/WeaponConsideration
    Model depth: 5
    """

    type_: str = Field(default="WeaponConsideration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class LifestyleModification(MedicalEntity):
    """A process of care involving exercise, changes to diet, fitness routines, and other lifestyle changes aimed
     at improving a health condition.

    See: https://schema.org/LifestyleModification
    Model depth: 3
    """

    type_: str = Field(default="LifestyleModification", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Manuscript(CreativeWork):
    """A book, document, or piece of music written by hand rather than typed or printed.

    See: https://schema.org/Manuscript
    Model depth: 3
    """

    type_: str = Field(default="Manuscript", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LegalService import LegalService


class Attorney(LegalService):
    """Professional service: Attorney. This type is deprecated - [[LegalService]] is more inclusive and less ambiguous.

    See: https://schema.org/Attorney
    Model depth: 5
    """

    type_: str = Field(default="Attorney", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class EnergyConsumptionDetails(Intangible):
    """EnergyConsumptionDetails represents information related to the energy efficiency of a product that consumes
     energy. The information that can be provided is based on international regulations such as for example [EU
     directive 2017/1369](https://eur-lex.europa.eu/eli/reg/2017/1369/oj) for energy labeling and the
     [Energy labeling rule](https://www.ftc.gov/enforcement/rules/rulemaking-regulatory-reform-proceedings/energy-water-use-labeling-consumer)
     under the Energy Policy and Conservation Act (EPCA) in the US.

    See: https://schema.org/EnergyConsumptionDetails
    Model depth: 3
    """

    type_: str = Field(default="EnergyConsumptionDetails", alias="@type", const=True)
    energyEfficiencyScaleMin: Optional[
        Union[
            List[Union["EUEnergyEfficiencyEnumeration", str]],
            "EUEnergyEfficiencyEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.",
    )
    hasEnergyEfficiencyCategory: Optional[
        Union[
            List[Union["EnergyEfficiencyEnumeration", str]],
            "EnergyEfficiencyEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.",
    )
    energyEfficiencyScaleMax: Optional[
        Union[
            List[Union["EUEnergyEfficiencyEnumeration", str]],
            "EUEnergyEfficiencyEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.EUEnergyEfficiencyEnumeration import (
        EUEnergyEfficiencyEnumeration,
    )
    from pydantic2_schemaorg.EnergyEfficiencyEnumeration import (
        EnergyEfficiencyEnumeration,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet


class HinduDiet(RestrictedDiet):
    """A diet conforming to Hindu dietary practices, in particular, beef-free.

    See: https://schema.org/HinduDiet
    Model depth: 5
    """

    type_: str = Field(default="HinduDiet", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class Substance(MedicalEntity):
    """Any matter of defined composition that has discrete existence, whose origin may be biological, mineral or
     chemical.

    See: https://schema.org/Substance
    Model depth: 3
    """

    type_: str = Field(default="Substance", alias="@type", const=True)
    maximumIntake: Optional[
        Union[List[Union["MaximumDoseSchedule", str]], "MaximumDoseSchedule", str]
    ] = Field(
        default=None,
        description="Recommended intake of this supplement for a given population as defined by a specific recommending authority.",
    )
    activeIngredient: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An active ingredient, typically chemical compounds and/or biologic substances.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MaximumDoseSchedule import MaximumDoseSchedule
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Rating(Intangible):
    """A rating is an evaluation on a numeric scale, such as 1 to 5 stars.

    See: https://schema.org/Rating
    Model depth: 3
    """

    type_: str = Field(default="Rating", alias="@type", const=True)
    worstRating: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The lowest value allowed in this rating system.",
    )
    reviewAspect: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="This Review or Rating is relevant to this part or facet of the itemReviewed.",
    )
    ratingExplanation: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='A short explanation (e.g. one to two sentences) providing background context and other information that led to the conclusion expressed in the rating. This is particularly applicable to ratings associated with "fact check" markup using [[ClaimReview]].',
    )
    author: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The author of this content or rating. Please note that author is special in that HTML 5 provides a special mechanism for indicating authorship via the rel tag. That is equivalent to this and may be used interchangeably.",
    )
    bestRating: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The highest value allowed in this rating system.",
    )
    ratingValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The rating for the content. Usage guidelines: * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ComputerLanguage(Intangible):
    """This type covers computer programming languages such as Scheme and Lisp, as well as other language-like computer
     representations. Natural languages are best represented with the [[Language]] type.

    See: https://schema.org/ComputerLanguage
    Model depth: 3
    """

    type_: str = Field(default="ComputerLanguage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableSizeSystemEnumeration import (
    WearableSizeSystemEnumeration,
)


class WearableSizeSystemCN(WearableSizeSystemEnumeration):
    """Chinese size system for wearables.

    See: https://schema.org/WearableSizeSystemCN
    Model depth: 6
    """

    type_: str = Field(default="WearableSizeSystemCN", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class RentalCarReservation(Reservation):
    """A reservation for a rental car. Note: This type is for information about actual reservations, e.g. in confirmation
     emails or HTML pages with individual confirmations of reservations.

    See: https://schema.org/RentalCarReservation
    Model depth: 4
    """

    type_: str = Field(default="RentalCarReservation", alias="@type", const=True)
    dropoffLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="Where a rental car can be dropped off.",
    )
    pickupTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="When a taxi will pick up a passenger or a rental car can be picked up.",
    )
    pickupLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="Where a taxi will pick up a passenger or a rental car can be picked up.",
    )
    dropoffTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="When a rental car can be dropped off.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.DateTime import DateTime



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DriveWheelConfigurationValue import (
    DriveWheelConfigurationValue,
)


class RearWheelDriveConfiguration(DriveWheelConfigurationValue):
    """Real-wheel drive is a transmission layout where the engine drives the rear wheels.

    See: https://schema.org/RearWheelDriveConfiguration
    Model depth: 6
    """

    type_: str = Field(default="RearWheelDriveConfiguration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
    MedicalObservationalStudyDesign,
)


class CaseSeries(MedicalObservationalStudyDesign):
    """A case series (also known as a clinical series) is a medical research study that tracks patients with a known
     exposure given similar treatment or examines their medical records for exposure and outcome. A case series
     can be retrospective or prospective and usually involves a smaller number of patients than the more powerful
     case-control studies or randomized controlled trials. Case series may be consecutive or non-consecutive,
     depending on whether all cases presenting to the reporting authors over a period of time were included, or
     only a selection.

    See: https://schema.org/CaseSeries
    Model depth: 6
    """

    type_: str = Field(default="CaseSeries", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class OverviewHealthAspect(HealthAspectEnumeration):
    """Overview of the content. Contains a summarized view of the topic with the most relevant information for an
     introduction.

    See: https://schema.org/OverviewHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="OverviewHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreateAction import CreateAction


class FilmAction(CreateAction):
    """The act of capturing sound and moving images on film, video, or digitally.

    See: https://schema.org/FilmAction
    Model depth: 4
    """

    type_: str = Field(default="FilmAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Product import Product


class ProductModel(Product):
    """A datasheet or vendor specification of a product (in the sense of a prototypical description).

    See: https://schema.org/ProductModel
    Model depth: 3
    """

    type_: str = Field(default="ProductModel", alias="@type", const=True)
    isVariantOf: Optional[
        Union[
            List[Union["ProductModel", "ProductGroup", str]],
            "ProductModel",
            "ProductGroup",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates the kind of product that this is a variant of. In the case of [[ProductModel]], this is a pointer (from a ProductModel) to a base product from which this product is a variant. It is safe to infer that the variant inherits all product features from the base model, unless defined locally. This is not transitive. In the case of a [[ProductGroup]], the group description also serves as a template, representing a set of Products that vary on explicitly defined, specific dimensions only (so it defines both a set of variants, as well as which values distinguish amongst those variants). When used with [[ProductGroup]], this property can apply to any [[Product]] included in the group.",
    )
    predecessorOf: Optional[
        Union[List[Union["ProductModel", str]], "ProductModel", str]
    ] = Field(
        default=None,
        description="A pointer from a previous, often discontinued variant of the product to its newer variant.",
    )
    successorOf: Optional[
        Union[List[Union["ProductModel", str]], "ProductModel", str]
    ] = Field(
        default=None,
        description="A pointer from a newer variant of a product to its previous, often discontinued predecessor.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.ProductGroup import ProductGroup



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DataType import DataType


class DateTime(DataType):
    """A combination of date and time of day in the form [-]CCYY-MM-DDThh:mm:ss[Z|(+|-)hh:mm] (see Chapter 5.4
     of ISO 8601).

    See: https://schema.org/DateTime
    Model depth: 5
    """

    type_: str = Field(default="DateTime", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct


class BankAccount(FinancialProduct):
    """A product or service offered by a bank whereby one may deposit, withdraw or transfer money and in some cases
     be paid interest.

    See: https://schema.org/BankAccount
    Model depth: 5
    """

    type_: str = Field(default="BankAccount", alias="@type", const=True)
    accountOverdraftLimit: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="An overdraft is an extension of credit from a lending institution when an account reaches zero. An overdraft allows the individual to continue withdrawing money even if the account has no funds in it. Basically the bank allows people to borrow a set amount of money.",
    )
    bankAccountType: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The type of a bank account.",
    )
    accountMinimumInflow: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="A minimum amount that has to be paid in every month.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class Project(Organization):
    """An enterprise (potentially individual but typically collaborative), planned to achieve a particular aim.
     Use properties from [[Organization]], [[subOrganization]]/[[parentOrganization]] to indicate project
     sub-structures.

    See: https://schema.org/Project
    Model depth: 3
    """

    type_: str = Field(default="Project", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.BioChemEntity import BioChemEntity


class MolecularEntity(BioChemEntity):
    """Any constitutionally or isotopically distinct atom, molecule, ion, ion pair, radical, radical ion, complex,
     conformer etc., identifiable as a separately distinguishable entity.

    See: https://schema.org/MolecularEntity
    Model depth: 3
    """

    type_: str = Field(default="MolecularEntity", alias="@type", const=True)
    inChIKey: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="InChIKey is a hashed version of the full InChI (using the SHA-256 algorithm).",
    )
    molecularFormula: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The empirical formula is the simplest whole number ratio of all the atoms in a molecule.",
    )
    chemicalRole: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="A role played by the BioChemEntity within a chemical context.",
    )
    inChI: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Non-proprietary identifier for molecular entity that can be used in printed and electronic data sources thus enabling easier linking of diverse data compilations.",
    )
    molecularWeight: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="This is the molecular weight of the entity being described, not of the parent. Units should be included in the form '&lt;Number&gt; &lt;unit&gt;', for example '12 amu' or as '&lt;QuantitativeValue&gt;.",
    )
    potentialUse: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="Intended use of the BioChemEntity by humans.",
    )
    monoisotopicMolecularWeight: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        description="The monoisotopic mass is the sum of the masses of the atoms in a molecule using the unbound, ground-state, rest mass of the principal (most abundant) isotope for each element instead of the isotopic average mass. Please include the units in the form '&lt;Number&gt; &lt;unit&gt;', for example '770.230488 g/mol' or as '&lt;QuantitativeValue&gt;.",
    )
    iupacName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Systematic method of naming chemical compounds as recommended by the International Union of Pure and Applied Chemistry (IUPAC).",
    )
    smiles: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A specification in form of a line notation for describing the structure of chemical species using short ASCII strings. Double bond stereochemistry indicators may need to be escaped in the string in formats where the backslash is an escape character.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LegalService import LegalService


class Notary(LegalService):
    """A notary.

    See: https://schema.org/Notary
    Model depth: 5
    """

    type_: str = Field(default="Notary", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FoodEstablishment import FoodEstablishment


class Bakery(FoodEstablishment):
    """A bakery.

    See: https://schema.org/Bakery
    Model depth: 5
    """

    type_: str = Field(default="Bakery", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class AdministrativeArea(Place):
    """A geographical region, typically under the jurisdiction of a particular government.

    See: https://schema.org/AdministrativeArea
    Model depth: 3
    """

    type_: str = Field(default="AdministrativeArea", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Permit(Intangible):
    """A permit issued by an organization, e.g. a parking pass.

    See: https://schema.org/Permit
    Model depth: 3
    """

    type_: str = Field(default="Permit", alias="@type", const=True)
    validUntil: Optional[Union[List[Union[date, "Date", str]], date, "Date", str]] = (
        Field(
            default=None,
            description="The date when the item is no longer valid.",
        )
    )
    validIn: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].",
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    issuedThrough: Optional[Union[List[Union["Service", str]], "Service", str]] = Field(
        default=None,
        description="The service through which the permit was granted.",
    )
    issuedBy: Optional[Union[List[Union["Organization", str]], "Organization", str]] = (
        Field(
            default=None,
            description="The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].",
        )
    )
    permitAudience: Optional[Union[List[Union["Audience", str]], "Audience", str]] = (
        Field(
            default=None,
            description="The target audience for this permit.",
        )
    )
    validFor: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of validity of a permit or similar thing.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Duration import Duration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MeasurementTypeEnumeration import MeasurementTypeEnumeration


class BodyMeasurementTypeEnumeration(MeasurementTypeEnumeration):
    """Enumerates types (or dimensions) of a person's body measurements, for example for fitting of clothes.

    See: https://schema.org/BodyMeasurementTypeEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="BodyMeasurementTypeEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InvestmentOrDeposit import InvestmentOrDeposit


class InvestmentFund(InvestmentOrDeposit):
    """A company or fund that gathers capital from a number of investors to create a pool of money that is then re-invested
     into stocks, bonds and other assets.

    See: https://schema.org/InvestmentFund
    Model depth: 6
    """

    type_: str = Field(default="InvestmentFund", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class SocialMediaPosting(Article):
    """A post to a social media platform, including blog posts, tweets, Facebook posts, etc.

    See: https://schema.org/SocialMediaPosting
    Model depth: 4
    """

    type_: str = Field(default="SocialMediaPosting", alias="@type", const=True)
    sharedContent: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="A CreativeWork such as an image, video, or audio clip shared as part of this posting.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ContactPoint import ContactPoint


class PostalAddress(ContactPoint):
    """The mailing address.

    See: https://schema.org/PostalAddress
    Model depth: 5
    """

    type_: str = Field(default="PostalAddress", alias="@type", const=True)
    addressCountry: Optional[
        Union[List[Union[str, "Text", "Country"]], str, "Text", "Country"]
    ] = Field(
        default=None,
        description="The country. For example, USA. You can also provide the two-letter [ISO 3166-1 alpha-2 country code](http://en.wikipedia.org/wiki/ISO_3166-1).",
    )
    postalCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The postal code. For example, 94043.",
    )
    streetAddress: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The street address. For example, 1600 Amphitheatre Pkwy.",
    )
    addressLocality: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The locality in which the street address is, and which is in the region. For example, Mountain View.",
    )
    postOfficeBoxNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The post office box number for PO box addresses.",
    )
    addressRegion: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The region in which the locality is, and which is in the country. For example, California or another appropriate first-level [Administrative division](https://en.wikipedia.org/wiki/List_of_administrative_divisions_by_country).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Country import Country



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure


class SubwayStation(CivicStructure):
    """A subway station.

    See: https://schema.org/SubwayStation
    Model depth: 4
    """

    type_: str = Field(default="SubwayStation", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicineSystem import MedicineSystem


class WesternConventional(MedicineSystem):
    """The conventional Western system of medicine, that aims to apply the best available evidence gained from the
     scientific method to clinical decision making. Also known as conventional or Western medicine.

    See: https://schema.org/WesternConventional
    Model depth: 6
    """

    type_: str = Field(default="WesternConventional", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class HealthAspectEnumeration(Enumeration):
    """HealthAspectEnumeration enumerates several aspects of health content online, each of which might be described
     using [[hasHealthAspect]] and [[HealthTopicContent]].

    See: https://schema.org/HealthAspectEnumeration
    Model depth: 4
    """

    type_: str = Field(default="HealthAspectEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Dermatologic(MedicalSpecialty):
    """Something relating to or practicing dermatology.

    See: https://schema.org/Dermatologic
    Model depth: 6
    """

    type_: str = Field(default="Dermatologic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ChooseAction import ChooseAction


class VoteAction(ChooseAction):
    """The act of expressing a preference from a fixed/finite/structured set of choices/options.

    See: https://schema.org/VoteAction
    Model depth: 5
    """

    type_: str = Field(default="VoteAction", alias="@type", const=True)
    candidate: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A sub property of object. The candidate subject of this action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class LaboratoryScience(MedicalSpecialty):
    """A medical science pertaining to chemical, hematological, immunologic, microscopic, or bacteriological
     diagnostic analyses or research.

    See: https://schema.org/LaboratoryScience
    Model depth: 6
    """

    type_: str = Field(default="LaboratoryScience", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PlanAction import PlanAction


class ReserveAction(PlanAction):
    """Reserving a concrete object. Related actions: * [[ScheduleAction]]: Unlike ScheduleAction, ReserveAction
     reserves concrete objects (e.g. a table, a hotel) towards a time slot / spatial allocation.

    See: https://schema.org/ReserveAction
    Model depth: 5
    """

    type_: str = Field(default="ReserveAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class BorrowAction(TransferAction):
    """The act of obtaining an object under an agreement to return it at a later date. Reciprocal of LendAction. Related
     actions: * [[LendAction]]: Reciprocal of BorrowAction.

    See: https://schema.org/BorrowAction
    Model depth: 4
    """

    type_: str = Field(default="BorrowAction", alias="@type", const=True)
    lender: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A sub property of participant. The person that lends the object being borrowed.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class DatedMoneySpecification(StructuredValue):
    """A DatedMoneySpecification represents monetary values with optional start and end dates. For example, this
     could represent an employee's salary over a specific period of time. __Note:__ This type has been superseded
     by [[MonetaryAmount]], use of that type is recommended.

    See: https://schema.org/DatedMoneySpecification
    Model depth: 4
    """

    type_: str = Field(default="DatedMoneySpecification", alias="@type", const=True)
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    currency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    amount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The amount of money.",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class HealthPlanCostSharingSpecification(Intangible):
    """A description of costs to the patient under a given network or formulary.

    See: https://schema.org/HealthPlanCostSharingSpecification
    Model depth: 3
    """

    type_: str = Field(
        default="HealthPlanCostSharingSpecification", alias="@type", const=True
    )
    healthPlanCoinsuranceOption: Optional[
        Union[List[Union[str, "Text"]], str, "Text"]
    ] = Field(
        default=None,
        description="Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?",
    )
    healthPlanCopayOption: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Whether the copay is before or after deductible, etc. TODO: Is this a closed set?",
        )
    )
    healthPlanCopay: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="The copay amount.",
    )
    healthPlanCoinsuranceRate: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The rate of coinsurance expressed as a number between 0.0 and 1.0.",
    )
    healthPlanPharmacyCategory: Optional[
        Union[List[Union[str, "Text"]], str, "Text"]
    ] = Field(
        default=None,
        description="The category or type of pharmacy associated with this cost sharing.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableSizeGroupEnumeration import (
    WearableSizeGroupEnumeration,
)


class WearableSizeGroupRegular(WearableSizeGroupEnumeration):
    """Size group \"Regular\" for wearables.

    See: https://schema.org/WearableSizeGroupRegular
    Model depth: 6
    """

    type_: str = Field(default="WearableSizeGroupRegular", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class UsageOrScheduleHealthAspect(HealthAspectEnumeration):
    """Content about how, when, frequency and dosage of a topic.

    See: https://schema.org/UsageOrScheduleHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="UsageOrScheduleHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReactAction import ReactAction


class DislikeAction(ReactAction):
    """The act of expressing a negative sentiment about the object. An agent dislikes an object (a proposition, topic
     or theme) with participants.

    See: https://schema.org/DislikeAction
    Model depth: 5
    """

    type_: str = Field(default="DislikeAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom


class MedicalSymptom(MedicalSignOrSymptom):
    """Any complaint sensed and expressed by the patient (therefore defined as subjective) like stomachache, lower-back
     pain, or fatigue.

    See: https://schema.org/MedicalSymptom
    Model depth: 5
    """

    type_: str = Field(default="MedicalSymptom", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Language(Intangible):
    """Natural languages such as Spanish, Tamil, Hindi, English, etc. Formal language code tags expressed in [BCP
     47](https://en.wikipedia.org/wiki/IETF_language_tag) can be used via the [[alternateName]] property.
     The Language type previously also covered programming languages such as Scheme and Lisp, which are now best
     represented using [[ComputerLanguage]].

    See: https://schema.org/Language
    Model depth: 3
    """

    type_: str = Field(default="Language", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class BoardingPolicyType(Enumeration):
    """A type of boarding policy used by an airline.

    See: https://schema.org/BoardingPolicyType
    Model depth: 4
    """

    type_: str = Field(default="BoardingPolicyType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Role import Role


class PerformanceRole(Role):
    """A PerformanceRole is a Role that some entity places with regard to a theatrical performance, e.g. in a Movie,
     TVSeries etc.

    See: https://schema.org/PerformanceRole
    Model depth: 4
    """

    type_: str = Field(default="PerformanceRole", alias="@type", const=True)
    characterName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The name of a character played in some acting or performing role, i.e. in a PerformanceRole.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from datetime import time, datetime, date
from decimal import Decimal
from typing import Any, Optional, ForwardRef, List, Union

from pydantic.v1 import BaseModel, Field, StrictBool, AnyUrl, StrictInt, StrictFloat
from pydantic.v1.typing import update_model_forward_refs

from pydantic2_schemaorg.ISO8601.ISO8601Date import ISO8601Date
from pydantic2_schemaorg.__types__ import types

updated_models = set()


class SchemaOrgBase(BaseModel):
    # JSON-LD fields
    reverse_: Optional[Any] = Field(default=None, alias="@reverse")
    id_: Optional[Any] = Field(default=None, alias="@id")
    context_: Optional[Any] = Field(default=None, alias="@context")
    graph_: Optional[Any] = Field(default=None, alias="@graph")

    def dict(self, *args, **kwargs):
        defaults = {"exclude_none": True, "by_alias": True}
        return super().dict(*args, **dict(defaults, **kwargs))

    def json(self, *args, **kwargs):
        defaults = {"exclude_none": True, "by_alias": True}
        return super().json(*args, **dict(defaults, **kwargs))

    class Config:
        allow_population_by_field_name = True

    @classmethod
    def get_classes_for_forward_ref(cls, field: Any) -> List[tuple]:
        classes = []
        if type(field.type_) == ForwardRef:
            t = field.type_
            u = t.__forward_code__
            v = u.co_consts
            for w in v:
                pydanticschema_org_type = types[w]
                mod = __import__(
                    pydanticschema_org_type[1], fromlist=[pydanticschema_org_type[0]]
                )
                class_ = getattr(mod, pydanticschema_org_type[0])
                classes.append((w, class_))
        return classes

    @classmethod
    def get_local_ns(cls):
        global updated_models
        localns = {}
        for k, v in cls.__fields__.items():
            classes = cls.get_classes_for_forward_ref(v)
            for class_name, class_ in classes:
                localns.update({class_name: class_})
        return localns

    @classmethod
    def update_forward_refs(cls, **localns: Any) -> None:
        """
        Try to update ForwardRefs on fields based on this Model, globalns and localns.
        """
        locals = {
            "Optional": Optional,
            "List": List,
            "Union": Union,
            "StrictBool": StrictBool,
            "AnyUrl": AnyUrl,
            "Decimal": Decimal,
            "time": time,
            "datetime": datetime,
            "date": date,
            "ISO8601Date": ISO8601Date,
            "StrictInt": StrictInt,
            "StrictFloat": StrictFloat,
        }
        for cls_ in cls.mro():
            if hasattr(cls_, "get_local_ns"):
                locals.update(cls_.get_local_ns())
        update_model_forward_refs(
            cls, cls.__fields__.values(), cls.__config__.json_encoders, locals
        )

    @classmethod
    def _update_all_fields(cls):
        for cls_ in cls.mro():
            if hasattr(cls_, "get_classes_for_forward_ref"):
                for k in cls_.__fields__.keys():
                    if k not in updated_models:
                        field = cls_.__fields__[k]
                        classes = cls_.get_classes_for_forward_ref(field)
                        for class_name, class_ in classes:
                            class_.update_forward_refs()

    def __init__(__pydantic_self__, **data: Any) -> None:
        __pydantic_self__.update_forward_refs()
        for k, v in data.items():
            if k in __pydantic_self__.__fields__.keys():
                if k not in updated_models:
                    field = __pydantic_self__.__fields__[k]
                    classes = __pydantic_self__.get_classes_for_forward_ref(field)
                    for class_name, class_ in classes:
                        class_.update_forward_refs()
        super().__init__(**data)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GameServerStatus import GameServerStatus


class OnlineFull(GameServerStatus):
    """Game server status: OnlineFull. Server is online but unavailable. The maximum number of players has reached.

    See: https://schema.org/OnlineFull
    Model depth: 6
    """

    type_: str = Field(default="OnlineFull", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalStudyStatus import MedicalStudyStatus


class Withdrawn(MedicalStudyStatus):
    """Withdrawn.

    See: https://schema.org/Withdrawn
    Model depth: 6
    """

    type_: str = Field(default="Withdrawn", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceComponentTypeEnumeration import (
    PriceComponentTypeEnumeration,
)


class CleaningFee(PriceComponentTypeEnumeration):
    """Represents the cleaning fee part of the total price for an offered product, for example a vacation rental.

    See: https://schema.org/CleaningFee
    Model depth: 5
    """

    type_: str = Field(default="CleaningFee", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class ItemPage(WebPage):
    """A page devoted to a single item, such as a particular product or hotel.

    See: https://schema.org/ItemPage
    Model depth: 4
    """

    type_: str = Field(default="ItemPage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Poster(CreativeWork):
    """A large, usually printed placard, bill, or announcement, often illustrated, that is posted to advertise
     or publicize something.

    See: https://schema.org/Poster
    Model depth: 3
    """

    type_: str = Field(default="Poster", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.StatusEnumeration import StatusEnumeration


class ActionStatusType(StatusEnumeration):
    """The status of an Action.

    See: https://schema.org/ActionStatusType
    Model depth: 5
    """

    type_: str = Field(default="ActionStatusType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class GovernmentOffice(LocalBusiness):
    """A government office&#x2014;for example, an IRS or DMV office.

    See: https://schema.org/GovernmentOffice
    Model depth: 4
    """

    type_: str = Field(default="GovernmentOffice", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class SeeDoctorHealthAspect(HealthAspectEnumeration):
    """Information about questions that may be asked, when to see a professional, measures before seeing a doctor
     or content about the first consultation.

    See: https://schema.org/SeeDoctorHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="SeeDoctorHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class MedicalBusiness(LocalBusiness):
    """A particular physical or virtual business of an organization for medical purposes. Examples of MedicalBusiness
     include different businesses run by health professionals.

    See: https://schema.org/MedicalBusiness
    Model depth: 4
    """

    type_: str = Field(default="MedicalBusiness", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CommunicateAction import CommunicateAction


class AskAction(CommunicateAction):
    """The act of posing a question / favor to someone. Related actions: * [[ReplyAction]]: Appears generally as
     a response to AskAction.

    See: https://schema.org/AskAction
    Model depth: 5
    """

    type_: str = Field(default="AskAction", alias="@type", const=True)
    question: Optional[Union[List[Union["Question", str]], "Question", str]] = Field(
        default=None,
        description="A sub property of object. A question.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Question import Question



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class TechArticle(Article):
    """A technical article - Example: How-to (task) topics, step-by-step, procedural troubleshooting, specifications,
     etc.

    See: https://schema.org/TechArticle
    Model depth: 4
    """

    type_: str = Field(default="TechArticle", alias="@type", const=True)
    dependencies: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Prerequisites needed to fulfill steps in article.",
    )
    proficiencyLevel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Proficiency needed for this content; expected values: 'Beginner', 'Expert'.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Grant(Intangible):
    """A grant, typically financial or otherwise quantifiable, of resources. Typically a [[funder]] sponsors
     some [[MonetaryAmount]] to an [[Organization]] or [[Person]], sometimes not necessarily via a dedicated
     or long-lived [[Project]], resulting in one or more outputs, or [[fundedItem]]s. For financial sponsorship,
     indicate the [[funder]] of a [[MonetaryGrant]]. For non-financial support, indicate [[sponsor]] of [[Grant]]s
     of resources (e.g. office space). Grants support activities directed towards some agreed collective goals,
     often but not always organized as [[Project]]s. Long-lived projects are sometimes sponsored by a variety
     of grants over time, but it is also common for a project to be associated with a single grant. The amount of a [[Grant]]
     is represented using [[amount]] as a [[MonetaryAmount]].

    See: https://schema.org/Grant
    Model depth: 3
    """

    type_: str = Field(default="Grant", alias="@type", const=True)
    funder: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports (sponsors) something through some kind of financial contribution.",
    )
    fundedItem: Optional[
        Union[
            List[
                Union[
                    "Event",
                    "CreativeWork",
                    "BioChemEntity",
                    "Person",
                    "MedicalEntity",
                    "Product",
                    "Organization",
                    str,
                ]
            ],
            "Event",
            "CreativeWork",
            "BioChemEntity",
            "Person",
            "MedicalEntity",
            "Product",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates something directly or indirectly funded or sponsored through a [[Grant]]. See also [[ownershipFundingInfo]].",
    )
    sponsor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.BioChemEntity import BioChemEntity
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.Product import Product



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.UserInteraction import UserInteraction


class UserPlusOnes(UserInteraction):
    """UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally
     better to use [[Action]]-based vocabulary, alongside types such as [[Comment]].

    See: https://schema.org/UserPlusOnes
    Model depth: 4
    """

    type_: str = Field(default="UserPlusOnes", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.DefinedTerm import DefinedTerm


class CategoryCode(DefinedTerm):
    """A Category Code.

    See: https://schema.org/CategoryCode
    Model depth: 4
    """

    type_: str = Field(default="CategoryCode", alias="@type", const=True)
    codeValue: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A short textual code that uniquely identifies the value.",
    )
    inCodeSet: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CategoryCodeSet", str]],
            AnyUrl,
            "URL",
            "CategoryCodeSet",
            str,
        ]
    ] = Field(
        default=None,
        description="A [[CategoryCodeSet]] that contains this category code.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.CategoryCodeSet import CategoryCodeSet



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Clip import Clip


class TVClip(Clip):
    """A short TV program or a segment/part of a TV program.

    See: https://schema.org/TVClip
    Model depth: 4
    """

    type_: str = Field(default="TVClip", alias="@type", const=True)
    partOfTVSeries: Optional[Union[List[Union["TVSeries", str]], "TVSeries", str]] = (
        Field(
            default=None,
            description="The TV series to which this episode or season belongs.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.TVSeries import TVSeries



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Podiatric(MedicalSpecialty, MedicalBusiness):
    """Podiatry is the care of the human foot, especially the diagnosis and treatment of foot disorders.

    See: https://schema.org/Podiatric
    Model depth: 5
    """

    type_: str = Field(default="Podiatric", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class MedicalEntity(Thing):
    """The most generic type of entity related to health and the practice of medicine.

    See: https://schema.org/MedicalEntity
    Model depth: 2
    """

    type_: str = Field(default="MedicalEntity", alias="@type", const=True)
    medicineSystem: Optional[
        Union[List[Union["MedicineSystem", str]], "MedicineSystem", str]
    ] = Field(
        default=None,
        description="The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.",
    )
    guideline: Optional[
        Union[List[Union["MedicalGuideline", str]], "MedicalGuideline", str]
    ] = Field(
        default=None,
        description="A medical guideline related to this entity.",
    )
    legalStatus: Optional[
        Union[
            List[Union[str, "Text", "DrugLegalStatus", "MedicalEnumeration"]],
            str,
            "Text",
            "DrugLegalStatus",
            "MedicalEnumeration",
        ]
    ] = Field(
        default=None,
        description="The drug or supplement's legal status, including any controlled substance schedules that apply.",
    )
    code: Optional[Union[List[Union["MedicalCode", str]], "MedicalCode", str]] = Field(
        default=None,
        description="A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.",
    )
    study: Optional[Union[List[Union["MedicalStudy", str]], "MedicalStudy", str]] = (
        Field(
            default=None,
            description="A medical study or trial related to this entity.",
        )
    )
    recognizingAuthority: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.",
    )
    relevantSpecialty: Optional[
        Union[List[Union["MedicalSpecialty", str]], "MedicalSpecialty", str]
    ] = Field(
        default=None,
        description="If applicable, a medical specialty in which this entity is relevant.",
    )
    funding: Optional[Union[List[Union["Grant", str]], "Grant", str]] = Field(
        default=None,
        description="A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicineSystem import MedicineSystem
    from pydantic2_schemaorg.MedicalGuideline import MedicalGuideline
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DrugLegalStatus import DrugLegalStatus
    from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration
    from pydantic2_schemaorg.MedicalCode import MedicalCode
    from pydantic2_schemaorg.MedicalStudy import MedicalStudy
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
    from pydantic2_schemaorg.Grant import Grant



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalCondition(MedicalEntity):
    """Any condition of the human body that affects the normal functioning of a person, whether physically or mentally.
     Includes diseases, injuries, disabilities, disorders, syndromes, etc.

    See: https://schema.org/MedicalCondition
    Model depth: 3
    """

    type_: str = Field(default="MedicalCondition", alias="@type", const=True)
    pathophysiology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.",
    )
    epidemiology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The characteristics of associated patients, such as age, gender, race etc.",
    )
    secondaryPrevention: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.",
    )
    riskFactor: Optional[
        Union[List[Union["MedicalRiskFactor", str]], "MedicalRiskFactor", str]
    ] = Field(
        default=None,
        description="A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age, coexisting condition.",
    )
    stage: Optional[
        Union[List[Union["MedicalConditionStage", str]], "MedicalConditionStage", str]
    ] = Field(
        default=None,
        description="The stage of the condition, if applicable.",
    )
    naturalProgression: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The expected progression of the condition if it is not treated and allowed to progress naturally.",
    )
    expectedPrognosis: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The likely outcome in either the short term or long term of the medical condition.",
    )
    associatedAnatomy: Optional[
        Union[
            List[
                Union[
                    "SuperficialAnatomy", "AnatomicalSystem", "AnatomicalStructure", str
                ]
            ],
            "SuperficialAnatomy",
            "AnatomicalSystem",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="The anatomy of the underlying organ system or structures associated with this entity.",
    )
    differentialDiagnosis: Optional[
        Union[List[Union["DDxElement", str]], "DDxElement", str]
    ] = Field(
        default=None,
        description="One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.",
    )
    possibleComplication: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.",
        )
    )
    primaryPrevention: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.",
    )
    signOrSymptom: Optional[
        Union[List[Union["MedicalSignOrSymptom", str]], "MedicalSignOrSymptom", str]
    ] = Field(
        default=None,
        description="A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition.",
    )
    typicalTest: Optional[
        Union[List[Union["MedicalTest", str]], "MedicalTest", str]
    ] = Field(
        default=None,
        description="A medical test typically performed given this condition.",
    )
    possibleTreatment: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A possible treatment to address this condition, sign or symptom.",
    )
    status: Optional[
        Union[
            List[Union[str, "Text", "EventStatusType", "MedicalStudyStatus"]],
            str,
            "Text",
            "EventStatusType",
            "MedicalStudyStatus",
        ]
    ] = Field(
        default=None,
        description="The status of the study (enumerated).",
    )
    drug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Specifying a drug or medicine used in a medication procedure.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy
    from pydantic2_schemaorg.MedicalRiskFactor import MedicalRiskFactor
    from pydantic2_schemaorg.MedicalConditionStage import MedicalConditionStage
    from pydantic2_schemaorg.SuperficialAnatomy import SuperficialAnatomy
    from pydantic2_schemaorg.AnatomicalSystem import AnatomicalSystem
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.DDxElement import DDxElement
    from pydantic2_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom
    from pydantic2_schemaorg.MedicalTest import MedicalTest
    from pydantic2_schemaorg.EventStatusType import EventStatusType
    from pydantic2_schemaorg.MedicalStudyStatus import MedicalStudyStatus
    from pydantic2_schemaorg.Drug import Drug



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalIndication(MedicalEntity):
    """A condition or factor that indicates use of a medical therapy, including signs, symptoms, risk factors, anatomical
     states, etc.

    See: https://schema.org/MedicalIndication
    Model depth: 3
    """

    type_: str = Field(default="MedicalIndication", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class WarrantyPromise(StructuredValue):
    """A structured value representing the duration and scope of services that will be provided to a customer free
     of charge in case of a defect or malfunction of a product.

    See: https://schema.org/WarrantyPromise
    Model depth: 4
    """

    type_: str = Field(default="WarrantyPromise", alias="@type", const=True)
    durationOfWarranty: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The duration of the warranty promise. Common unitCode values are ANN for year, MON for months, or DAY for days.",
    )
    warrantyScope: Optional[
        Union[List[Union["WarrantyScope", str]], "WarrantyScope", str]
    ] = Field(
        default=None,
        description="The scope of the warranty promise.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.WarrantyScope import WarrantyScope



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeries import CreativeWorkSeries


class PodcastSeries(CreativeWorkSeries):
    """A podcast is an episodic series of digital audio or video files which a user can download and listen to.

    See: https://schema.org/PodcastSeries
    Model depth: 4
    """

    type_: str = Field(default="PodcastSeries", alias="@type", const=True)
    actor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.",
    )
    webFeed: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DataFeed", str]], AnyUrl, "URL", "DataFeed", str
        ]
    ] = Field(
        default=None,
        description="The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.DataFeed import DataFeed



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class OwnershipInfo(StructuredValue):
    """A structured value providing information about when a certain organization or person owned a certain product.

    See: https://schema.org/OwnershipInfo
    Model depth: 4
    """

    type_: str = Field(default="OwnershipInfo", alias="@type", const=True)
    acquiredFrom: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The organization or person from which the product was acquired.",
    )
    ownedThrough: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date and time of giving up ownership on the product.",
    )
    ownedFrom: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date and time of obtaining the product.",
    )
    typeOfGood: Optional[
        Union[List[Union["Service", "Product", str]], "Service", "Product", str]
    ] = Field(
        default=None,
        description="The product that this structured value is referring to.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Product import Product



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugPrescriptionStatus import DrugPrescriptionStatus


class OTC(DrugPrescriptionStatus):
    """The character of a medical substance, typically a medicine, of being available over the counter or not.

    See: https://schema.org/OTC
    Model depth: 6
    """

    type_: str = Field(default="OTC", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Collection(CreativeWork):
    """A collection of items, e.g. creative works or products.

    See: https://schema.org/Collection
    Model depth: 3
    """

    type_: str = Field(default="Collection", alias="@type", const=True)
    collectionSize: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of items in the [[Collection]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Church import Church


class CatholicChurch(Church):
    """A Catholic church.

    See: https://schema.org/CatholicChurch
    Model depth: 6
    """

    type_: str = Field(default="CatholicChurch", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementChest(BodyMeasurementTypeEnumeration):
    """Maximum girth of chest. Used, for example, to fit men's suits.

    See: https://schema.org/BodyMeasurementChest
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementChest", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyOfWater import BodyOfWater


class Waterfall(BodyOfWater):
    """A waterfall, like Niagara.

    See: https://schema.org/Waterfall
    Model depth: 5
    """

    type_: str = Field(default="Waterfall", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.QualitativeValue import QualitativeValue


class DriveWheelConfigurationValue(QualitativeValue):
    """A value indicating which roadwheels will receive torque.

    See: https://schema.org/DriveWheelConfigurationValue
    Model depth: 5
    """

    type_: str = Field(
        default="DriveWheelConfigurationValue", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIntangible import MedicalIntangible


class DrugLegalStatus(MedicalIntangible):
    """The legal availability status of a medical drug.

    See: https://schema.org/DrugLegalStatus
    Model depth: 4
    """

    type_: str = Field(default="DrugLegalStatus", alias="@type", const=True)
    applicableLocation: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The location in which the status applies.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialService import FinancialService


class BankOrCreditUnion(FinancialService):
    """Bank or credit union.

    See: https://schema.org/BankOrCreditUnion
    Model depth: 5
    """

    type_: str = Field(default="BankOrCreditUnion", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Message import Message


class EmailMessage(Message):
    """An email message.

    See: https://schema.org/EmailMessage
    Model depth: 4
    """

    type_: str = Field(default="EmailMessage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class ItemAvailability(Enumeration):
    """A list of possible product availability options.

    See: https://schema.org/ItemAvailability
    Model depth: 4
    """

    type_: str = Field(default="ItemAvailability", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalStudyStatus import MedicalStudyStatus


class Recruiting(MedicalStudyStatus):
    """Recruiting participants.

    See: https://schema.org/Recruiting
    Model depth: 6
    """

    type_: str = Field(default="Recruiting", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalPlatformEnumeration import DigitalPlatformEnumeration


class IOSPlatform(DigitalPlatformEnumeration):
    """Represents the broad notion of iOS-based operating systems.

    See: https://schema.org/IOSPlatform
    Model depth: 5
    """

    type_: str = Field(default="IOSPlatform", alias="@type", const=True)
